
# Type: affects


describes an entity that has a direct affect on the state or quality of another existing entity. Use of the 'affects' predicate implies that the affected entity already exists, unlike predicates such as 'affects risk for' and 'prevents, where the outcome is something that may or may not come to be.

URI: [biolink:affects](https://w3id.org/biolink/vocab/affects)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [affects abundance of](affects_abundance_of.md)
 *  [affects activity of](affects_activity_of.md)
 *  [affects degradation of](affects_degradation_of.md)
 *  [affects expression of](affects_expression_of.md)
 *  [affects folding of](affects_folding_of.md)
 *  [affects localization of](affects_localization_of.md)
 *  [affects metabolic processing of](affects_metabolic_processing_of.md)
 *  [affects molecular modification of](affects_molecular_modification_of.md)
 *  [affects mutation rate of](affects_mutation_rate_of.md)
 *  [affects response to](affects_response_to.md)
 *  [affects secretion of](affects_secretion_of.md)
 *  [affects splicing of](affects_splicing_of.md)
 *  [affects stability of](affects_stability_of.md)
 *  [affects synthesis of](affects_synthesis_of.md)
 *  [affects transport of](affects_transport_of.md)
 *  [affects uptake of](affects_uptake_of.md)
 *  [disrupts](disrupts.md)
 *  [regulates](regulates.md)
 *  [treats](treats.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SEMMEDDB:AFFECTS |
| **In Subsets:** | | translator_minimal |

